# To customize the measurement (ruler) menu, save a copy of this script in $HOME/.qub-express/MeasurementScripts/

# The following function is called in the main thread, prior to measuring;  you can return identical or modified args.
#    * segments: list of qubx.data_types.SourceSeg, one per measurement
#    * table: destination of measurements
#    * row_offset: first row index to put measurements in
def before_measure(segments, table, row_offset):
    return segments, table, row_offset

# The following function is called on each selection to be measured.
#    * segment: qubx.data_types.SourceSeg of source_signal
#    * signals: list representing each data signal; provides:
#      signals[i].name: e.g. "Current"
#      signals[i].get_samples(): returns numpy.array(dtype=float32)
#      signals[i].hidden: True if user has put the signal offscreen
#    * source_signal: the entry in signals which is chosen in Data Source
#    * inclusion_mask: numpy.array(dtype=bool): whether each sample is included (True) or excluded (False)
#    * measured: a dictionary to store results in
# It is called in a worker thread, so please don't interact with the rest of the program directly (use gobject.idle_add).
def measure_selection(segment, signals, source_signal, inclusion_mask, measured):
    for signal in signals:
    # for signal in [source_signal]: # alternatively, measure just the active signal
        if not signal.hidden:
            samples = signal.get_samples()
            samples_included = samples[inclusion_mask]
            if len(samples_included) == 0:
                return
            measured['%s Mean' % signal.name] = samples_included.mean()
            measured['%s Std' % signal.name] = samples_included.std()
            measured['%s Min' % signal.name] = samples_included.min()
            measured['%s Max' % signal.name] = samples_included.max()
            ipeak = samples_included.argmax()
            if samples_included[ipeak] < 0:
                ipeak = samples_included.argmin()
            measured['%s Peak_ms' % signal.name] = ipeak * segment.sampling * 1e3
            measured['%s Peak' % signal.name] = samples_included[ipeak]
            one_pct = max(1, int(round(.01 * len(samples))))
            measured['%s Initial' % signal.name] = samples[:one_pct].mean()
            measured['%s Final' % signal.name] = samples[-one_pct:].mean()
            
    if segment.idealized:
        qubx.dataGTK.measure_selection_idealized(segment, source_signal, measured)


# The following function is called in the main thread, after a measurement sequence is completed.
#    * segments: list of qubx.data_types.SourceSeg, one per measurement
#    * table: qubx.table.Table containing results
#    * row_offset: first row index of results in table
def after_measure(segments, table, row_offset):
    pass

